==> kubernetes-model-1.0.60-sources.jar: annotations/io/fabric8/kubernetes/api/model/FlockerVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class FlockerVolumeSourceBuilder extends FlockerVolumeSourceFluentImpl<FlockerVolumeSourceBuilder> implements VisitableBuilder<FlockerVolumeSource,FlockerVolumeSourceBuilder>{

    FlockerVolumeSourceFluent<?> fluent;
    Boolean validationEnabled;

    public FlockerVolumeSourceBuilder(){
            this(true);
    }
    public FlockerVolumeSourceBuilder(Boolean validationEnabled){
            this(new FlockerVolumeSource(), validationEnabled);
    }
    public FlockerVolumeSourceBuilder(FlockerVolumeSourceFluent<?> fluent){
            this(fluent, true);
    }
    public FlockerVolumeSourceBuilder(FlockerVolumeSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new FlockerVolumeSource(), validationEnabled);
    }
    public FlockerVolumeSourceBuilder(FlockerVolumeSourceFluent<?> fluent,FlockerVolumeSource instance){
            this(fluent, instance, true);
    }
    public FlockerVolumeSourceBuilder(FlockerVolumeSourceFluent<?> fluent,FlockerVolumeSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withDatasetName(instance.getDatasetName()); 
            this.validationEnabled = validationEnabled; 
    }
    public FlockerVolumeSourceBuilder(FlockerVolumeSource instance){
            this(instance,true);
    }
    public FlockerVolumeSourceBuilder(FlockerVolumeSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withDatasetName(instance.getDatasetName()); 
            this.validationEnabled = validationEnabled; 
    }

    public FlockerVolumeSource build(){
            FlockerVolumeSource buildable = new FlockerVolumeSource(fluent.getDatasetName());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            FlockerVolumeSourceBuilder that = (FlockerVolumeSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: annotations/io/fabric8/kubernetes/api/model/FlockerVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class FlockerVolumeSourceBuilder extends FlockerVolumeSourceFluentImpl<FlockerVolumeSourceBuilder> implements VisitableBuilder<FlockerVolumeSource,FlockerVolumeSourceBuilder>{

    FlockerVolumeSourceFluent<?> fluent;
    Boolean validationEnabled;

    public FlockerVolumeSourceBuilder(){
            this(true);
    }
    public FlockerVolumeSourceBuilder(Boolean validationEnabled){
            this(new FlockerVolumeSource(), validationEnabled);
    }
    public FlockerVolumeSourceBuilder(FlockerVolumeSourceFluent<?> fluent){
            this(fluent, true);
    }
    public FlockerVolumeSourceBuilder(FlockerVolumeSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new FlockerVolumeSource(), validationEnabled);
    }
    public FlockerVolumeSourceBuilder(FlockerVolumeSourceFluent<?> fluent,FlockerVolumeSource instance){
            this(fluent, instance, true);
    }
    public FlockerVolumeSourceBuilder(FlockerVolumeSourceFluent<?> fluent,FlockerVolumeSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withDatasetName(instance.getDatasetName()); 
            this.validationEnabled = validationEnabled; 
    }
    public FlockerVolumeSourceBuilder(FlockerVolumeSource instance){
            this(instance,true);
    }
    public FlockerVolumeSourceBuilder(FlockerVolumeSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withDatasetName(instance.getDatasetName()); 
            this.validationEnabled = validationEnabled; 
    }

    public FlockerVolumeSource build(){
            FlockerVolumeSource buildable = new FlockerVolumeSource(fluent.getDatasetName());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            FlockerVolumeSourceBuilder that = (FlockerVolumeSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
